ryvencore.script\_variables.VarsManager module
==============================================

.. automodule:: ryvencore.script_variables.VarsManager
   :members:
   :undoc-members:
   :show-inheritance:
